from __future__ import absolute_import
import click
import niftianon.anonymiser


@click.command()
@click.argument('identifiable_image', type=click.Path(exists=True))
@click.argument('anonymised_image', type=click.Path(exists=False))
def anonymise(identifiable_image, anonymised_image):
    """Anonymise IDENTIFIABLE_IMAGE and save the result to ANONYMISED_IMAGE

    IDENTIFIABLE_IMAGE must be the path to a NIFTI or NIFTI_GZ format image
    ANONYMISED_IMAGE must be a path that does not currently exist
    """

    niftianon.anonymiser.anonymise(identifiable_image, anonymised_image)



import nibabel


def anonymise(identifiable_path, anonymous_path):
    # read identifiable data
    identifiable = nibabel.load(identifiable_path)
    identifiable_data = identifiable.get_data()

    # create an anonymous image with the identifiable voxels and affine
    anonymised = nibabel.Nifti1Image(identifiable_data, identifiable.affine)

    # copy header fields from the identifiable to anonymised images
    anonymised.header.set_data_dtype(identifiable.header.get_data_dtype())
    qform, qform_code = identifiable.get_qform(coded=True)
    anonymised.set_qform(qform, code=int(qform_code))
    sform, sform_code = identifiable.get_sform(coded=True)
    anonymised.set_sform(sform, code=int(sform_code))
    anonymised.header.set_xyzt_units(*identifiable.header.get_xyzt_units())
    anonymised.header.set_slope_inter(*identifiable.header.get_slope_inter())
    anonymised.header['pixdim'] = identifiable.header['pixdim']

    # save the anonymised image
    nibabel.save(anonymised, anonymous_path)



from setuptools import setup


def readme():
    with open('README.rst') as f:
        return f.read()


setup(
    name='niftianon',
    version='0.1.0',
    packages=['niftianon'],
    zip_safe=True,
    author='Jon Stutters',
    author_email='j.stutters@ucl.ac.uk',
    description='Anonymiser for NIFTI images',
    long_description=readme(),
    url='https://github.com/jstutters/niftianon',
    include_package_data=True,
    install_requires=[
        'Click',
        'nibabel'
    ],
    entry_points='''
        [console_scripts]
        niftianon=niftianon.cli:anonymise
    ''',
    license='MIT',
    classifiers=[
    ]
)
